Returns the incidence matrix of the AS-PCD
whose vertices are the given 2D numerical data set, Xp,
in the triangle tri\(=T(v=1,v=2,v=3)\).
AS proximity regions are defined with respect to the triangle tri\(=T(v=1,v=2,v=3)\) and
vertex regions are based on the center, \(M=(m_1,m_2)\) in Cartesian coordinates
or \(M=(\alpha,\beta,\gamma)\) in barycentric coordinates
in the interior of the triangle tri
or based on circumcenter of tri;
default is M="CC", i.e., circumcenter of tri.
Loops are allowed, so the diagonal entries are all equal to 1.
See also (ceyhan:Phd-thesis,ceyhan:comp-geo-2010,ceyhan:mcap2012;textualpcds).